scikit-fda
==========

|build-status| |docs|

scikit-fda: Functional Data Analysis in Python

Functional Data Analysis is the field of Statistics that analyses data that
come in the shape of functions. To know more about fda have a look at fda_ or read [RS05]_.

This package offers classes, methods and functions to give support to fda
in Python. The idea is to give a wide range of utils to work with functional data
in Python. This utils include discrete points and basis representation of functional
data and allows to calculate basic statistics such as mean, variance or covariance,
smooth the functional data, calculate norms, distances, perform linear regression and
much more.

For more information read the documentation.

Installation
============

Under construction. 

.. todo:: installation

Requirements
------------

fda is available in Python 3.5 or above, in all operating systems.

.. todo:: test for other python versions

Documentation
=============
The documentation can be found in https://fda.readthedocs.io/en/latest/

References
==========

.. [RS05] Ramsay, J., Silverman, B. W. (2005). *Functional Data Analysis*. Springer.

.. _fda: http://www.functionaldata.org/

.. |build-status| image:: https://travis-ci.org/GAA-UAM/scikit-fda.svg
    :alt: build status
    :scale: 100%
    :target: https://travis-ci.org/GAA-UAM/scikit-fda

.. |docs| image:: https://readthedocs.org/projects/fda/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: http://fda.readthedocs.io/en/latest/?badge=latest
